
     _____                      
    |  __ \                     
    | |__) |_ _ _ __  _   _ ___ 
    |  ___/ _` | '_ \| | | / __|
    | |  | (_| | |_) | |_| \__ \
    |_|   \__,_| .__/ \__, |___/
               | |     __/ |    
               |_|    |___/     
     Python Rest-API as DAG

## Description
Rest-API as DAG is an approach in which the sequence of a request up to the response is described declaratively as a graph (hence Directed Acyclic Graph). This approach has crucial advantages:
1. The readability of the code is increased, the process could also be easily represented graphically and
2. the individual steps can be structured and reused in a natural way.
Papys is a concrete implementation of this approach. It also offers further advantages and is easy to use!

## Status
The library is in an early stage of version 0.4.0 with target release 1.0.0 until end of 2024.

## Project website
The official project website is here: https://papys.asderix.com/ - Roadmap and release notes are on GitHub-Wiki.

## Usage
You find a start guide with examples on the the wiki: https://github.com/asderix/Papys/wiki

## Install
pip install papys

## Bugs & features
Please report bugs or missed features to: info@asderix.com.